"""Top-level package for dmriprep."""
from .__about__ import (
    __version__,
    __copyright__,
    __credits__,
    __packagename__,
)

__all__ = [
    "__version__",
    "__copyright__",
    "__credits__",
    "__packagename__",
]
